@@ -6,6 +6,6 @@ use parent qw(Sub::Meta::Parameters);
 use MySubMeta::Param;
 
 # override
-sub param_class { 'MySubMeta::Param' }
+sub param_class { return 'MySubMeta::Param' }
 
 1;
